@@ -9,7 +9,10 @@ get_ipython: Callable
 
 
 def yaml_load(s: str):
-    return yaml.load(s, Loader=yaml.FullLoader)
+    if yaml.__version__[0] >= '5':
+        return yaml.load(s, Loader=yaml.FullLoader)
+    else:
+        return yaml.load(s)
 
 
 def yaml_dump(obj: any):
@@ -48,5 +51,29 @@ def is_ipynb():
         return False
 
 
+def is_ipynb_pycharm():
+    if not is_ipynb():
+        return False
+
+    if is_colab() or is_kaggle():
+        return False
+
+    import os
+    if '_' not in os.environ:
+        return True
+    else:
+        return False
+
+
+def is_colab():
+    import sys
+    return 'google.colab' in sys.modules
+
+
+def is_kaggle():
+    import sys
+    return 'kaggle_gcp' in sys.modules
+
+
 if __name__ == '__main__':
     print(is_ipynb())
